import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import iwork.eheap2.*;
import iwork.icrafter.uigen.*;
import iwork.icrafter.remote.*;
import iwork.icrafter.system.*;

/**
 * Servlet that handles all the possible services of the room
 */

public class VoiceServices extends HttpServlet {
    
    public EventHeap eh;
    public EHCallObject ehc;
    //the path of the light VXML code
    private String lightpath = "D:\\istuff\\voice\\lightservices.vxml";
    //the path of the beginning of the VXML service
    private String welcomepath = "D:\\istuff\\voice\\welcome.vxml";
    //the path of the projector VXML code
    private String projectorpath = "D:\\istuff\\voice\\projectorservices.vxml";
    private String butlerpath = "D:\\istuff\\voice\\butlerservices.vxml";
    private String event_heap = "iw-room2";
    //service name of the light controller
    private String light_service = 
	"iwork.icrafter.services.devices.LightController";
    
    /**
     * It returns a vxml webpage and processes the event associated 
     * with the request.
     * @param request the request that is made to the servlet to be processed
     * @param response the response to send back to the service that requested
     *                 the necessary action
     * 
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response)
	throws ServletException, IOException {
	response.setContentType("text/vxml");
	PrintWriter out = response.getWriter();
	String command = request.getParameter("command");
	try {
	    eh = new EventHeap(event_heap);
	    ehc = new EHCallObject(eh);
	}
	catch (Exception e) {
	    this.outputVXML(lightpath, out);
	}
	//if the command is lights, then returns the light VXML code
	if (command.equals("lights")) {
	    this.outputVXML(lightpath, out);
	}
	//turns the lights on/off and returns to the start of the voice services
	if (command.equals("lightaction")) { 
	    try {
		String action = request.getParameter("action");
		ehc.ehIFCall(light_service, action, null, null);
		System.out.println(action);
		this.outputVXML(welcomepath, out);
	    }
	    catch (Exception e) {
		e.printStackTrace();
	    }
	}
	// if the command is projectors, returns the projector VXML code
	if (command.equals("projectors")) {
	    this.outputVXML(projectorpath, out);
	}
	// performs projector actions such as power on/power off
	if (command.equals("projectoraction")) {
	    String projno = request.getParameter("projector");
	    String action = request.getParameter("action");
	    //if the projector action is performed on all
	    if (projno.equals("all")) {
		try {
		    ehc.ehIFCall("iwork.icrafter.services.devices.ProjectorController", action, null, null);
		    System.out.println("projector " + action);
		    this.outputVXML(welcomepath, out);
		    return;
		}
		catch (Exception e) {
		    e.printStackTrace();
		}
	    }
	    // if the projector action is to display the laptop
	    if (action.equals("computer2") && !(projno.equals("all"))) {
		try {
		    Serializable[] param = new String[1];
		    param[0] = "computer2";
		    ehc.ehCall(projno, "input", param);
		    System.out.println("laptop on " + projno);
		    this.outputVXML(welcomepath, out);
		    return;
		}
		catch (Exception e) {
		    e.printStackTrace();
		}
	    }
	    //otherwise it performs an ehCall on the other actions 
	    //must be appropriate to the icrafter services
	    else {
		try {
		    ehc.ehCall(projno, action);
		    System.out.println(projno + " " + action);
		    this.outputVXML(welcomepath, out);
		}
		catch (Exception e) {
		    e.printStackTrace();
		}
	    }
	}
	//performs the actions associated with the projector such as 
	//displaying a url
	if (command.equals("butler")) {
	    this.outputVXML(butlerpath, out);
	}
	if (command.equals("butleraction")) {
	    System.out.println("butler part one");
	    String action;
	    String projno = request.getParameter("projector");
	    String url = request.getParameter("url");
	    Serializable[] param = new String[1];
	    param[0] = url;
	    try {  
		//	if (url != null) {
		Serializable[] param = new String[1];
		param[0] = url;
		ehc.ehCall(projno, "display", param);
		System.out.println("displaying: " + url);
		this.outputVXML(welcomepath, out);
	    }
	    catch (Exception e) {
		e.printStackTrace();
	    }
	}	
	    
    }

    /**
     * Takes in a file and outputs each of the line into the PrintWriter.
     *
     * @param pathname the path where the file can be found
     * @param out the PrintWriter output associated with this file
     */
    private void outputVXML(String pathname, PrintWriter out) {
	try {
	    // the input of the file
	    BufferedReader input = new BufferedReader(new FileReader(pathname));
	    String line = input.readLine();
	    //while there are still lines in the input, attach it to the output
	    while (line != null) {
		out.println(line);
		line = input.readLine();
	    }
	}
	catch (Exception e) {
	    e.printStackTrace();
	}
    }
}
